==> snipe-it-5.1.8.zip: snipe-it-5.1.8/resources/lang/tr/help.php <==
<?php

return array(

    /*
    |--------------------------------------------------------------------------
    | Password Reminder Language Lines
    |--------------------------------------------------------------------------
    |
    | The following language lines are the default lines which match reasons
    | that are given by the password broker for a password update attempt
    | has failed, such as for an invalid token or invalid new password.
    |
    */

    "more_info_title" => "Daha Fazla Bilgi",

    "audit_help" => "Bu kutucuğu işaretlediğinizde varlık kaydı yeni lokasyonu gösterir. İşaretlenmemiş olarak bırakırsanız denetim kayıtlarında basitçe lokasyonu not edecektir. <br><br>Eğer varlığın çıkışı yapılmışsa, çıkışı yapılan kişiyi, varlığı veya lokasyonu değiştirmeyecektir.",

    'assets' => 'Varlıklar seri numaraları veya varlık etiketleri ile takip edilir. Bunlar bir öğeyi belirlemek için daha yüksek öneme sahip olma eğilimindedir.',

    'categories' => 'Kategoriler öğelerinizi düzenlemenize yardımcı olur. Örneğin &quot;Masaüstü&quot;, &quot;Dizüstü&quot;, &quot;Cep Telefonları&quot;, &quot;Tabletler&quot; vb, ancak kategorileri size mantıklı gelen herhangi bir şekilde de kullanabilirsiniz.',

    'accessories' => 'Aksesuarlar kullanıcılara verdiğiniz ekipmanlardır; fakat seri numaraları yoktur (ya da siz tek tek takip etmeyi önemsemiyorsunuzdur). Örneğin fare, klavye vs.',

    'companies'     => 'Şirketler basit bir tanımlayıcı alanı olarak kullanılabilir veya Yönetici ayarlarınızda tam şirket desteğinin etkinleştirilmesi durumunda varlıkların, kullanıcıların vb. görünürlüklerini sınırlamak için kullanılabilir.',

    'components'    => 'Bileşenler, bir demirbaşın parçası olan öğelerdir, örneğin HDD, RAM vb.',

    'consumables'   => 'Sarf malzemeleri satın alınan ve zamanla tüketilen ürünlerdir. Örneğin yazıcı kartuşu, fotokopi kağıdı vs.',

    'depreciations' => 'Demirbaş amortismanını sabit bir oran ile düşecek şekilde ayarlayabilirsiniz.',



);

==> snipe-it-5.4.3.zip: snipe-it-5.4.3/resources/lang/tr/help.php <==
<?php

return [

    /*
    |--------------------------------------------------------------------------
    | Password Reminder Language Lines
    |--------------------------------------------------------------------------
    |
    | The following language lines are the default lines which match reasons
    | that are given by the password broker for a password update attempt
    | has failed, such as for an invalid token or invalid new password.
    |
    */

    'more_info_title' => 'Daha Fazla Bilgi',

    'audit_help' => 'Bu kutucuğu işaretlediğinizde varlık kaydı yeni lokasyonu gösterir. İşaretlenmemiş olarak bırakırsanız denetim kayıtlarında basitçe lokasyonu not edecektir. <br><br>Eğer varlığın çıkışı yapılmışsa, çıkışı yapılan kişiyi, varlığı veya lokasyonu değiştirmeyecektir.',

    'assets' => 'Varlıklar seri numaraları veya varlık etiketleri ile takip edilir. Bunlar bir öğeyi belirlemek için daha yüksek öneme sahip olma eğilimindedir.',

    'categories' => 'Kategoriler öğelerinizi düzenlemenize yardımcı olur. Örneğin &quot;Masaüstü&quot;, &quot;Dizüstü&quot;, &quot;Cep Telefonları&quot;, &quot;Tabletler&quot; vb, ancak kategorileri size mantıklı gelen herhangi bir şekilde de kullanabilirsiniz.',

    'accessories' => 'Aksesuarlar kullanıcılara verdiğiniz ekipmanlardır; fakat seri numaraları yoktur (ya da siz tek tek takip etmeyi önemsemiyorsunuzdur). Örneğin fare, klavye vs.',

    'companies'     => 'Şirketler basit bir tanımlayıcı alanı olarak kullanılabilir veya Yönetici ayarlarınızda tam şirket desteğinin etkinleştirilmesi durumunda varlıkların, kullanıcıların vb. görünürlüklerini sınırlamak için kullanılabilir.',

    'components'    => 'Bileşenler, bir demirbaşın parçası olan öğelerdir, örneğin HDD, RAM vb.',

    'consumables'   => 'Sarf malzemeleri satın alınan ve zamanla tüketilen ürünlerdir. Örneğin yazıcı kartuşu, fotokopi kağıdı vs.',

    'depreciations' => 'Demirbaş amortismanını sabit bir oran ile düşecek şekilde ayarlayabilirsiniz.',

];
